@@ -46,10 +46,10 @@ async def get_ship_name(infolist:List):
             "shipType":param_shiptype
         }
         url = 'https://api.wows.shinoaki.com/public/wows/encyclopedia/ship/search'
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
-            logger.info(f"本次请求返回的状态码:{resp.status_code}")
+            logger.success(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
         if result['data']:
             for ship in result['data']:
@@ -72,10 +72,10 @@ async def get_ship_byName(shipname:str):
         "shipName":shipname,
         "shipType":''
     }
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
-            logger.info(f"本次请求返回的状态码:{resp.status_code}")
+            logger.success(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
         List = []
         if result['code'] == 200 and result['data']:
@@ -97,10 +97,10 @@ async def get_AccountIdByName(server:str,name:str):
             "server": server,
             "userName": name
         }
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
-            logger.info(f"本次请求返回的状态码:{resp.status_code}")
+            logger.success(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
         if result['code'] == 200 and result['data']:
             return result['data']['accountId']
