@@ -37,11 +37,11 @@ async def get_BindInfo(server_type,user,info):
                 return '参数似乎出了问题呢，请使用me或@群友'
         else:
             return '参数似乎出了问题呢，请使用me或@群友'
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
-            logger.info(f"本次请求返回的状态码:{result['code']}")
+            logger.success(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
             if result['data']:
                 msg1 = f'当前绑定账号\n'
@@ -90,11 +90,11 @@ async def set_BindInfo(server_type,user,info):
                 return '参数似乎输错了呢，请确保后面跟随服务器+游戏昵称'
         else:
             return '参数似乎输错了呢，请确保后面跟随服务器+游戏昵称'
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
-            logger.info(f"本次请求返回的状态码:{result['code']}")
+            logger.success(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
             return '绑定成功'
         elif result['code'] == 500:
@@ -118,11 +118,11 @@ async def change_BindInfo(server_type,user,info):
             }
         else:
             return '参数似乎出了问题呢，请跟随要切换的序号'
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
-            logger.info(f"本次请求返回的状态码:{result['code']}")
+            logger.success(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
             if result['data'] and len(result['data']) >= int(info[0]):
                 account_name = result['data'][int(info[0])-1]['userName']
@@ -180,11 +180,11 @@ async def set_special_BindInfo(server_type,user,info):
                 return '参数似乎输错了呢，请确保后面跟随服务器+网页查询到的AccountID'
         else:
             return '参数似乎输错了呢，请确保后面跟随服务器+游戏昵称'
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
-            logger.info(f"本次请求返回的状态码:{result['code']}")
+            logger.success(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
             return '绑定成功'
         elif result['code'] == 500:
@@ -228,11 +228,11 @@ async def delete_BindInfo(server_type,user,info):
             return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
             return f"{result['message']}"
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
-            logger.info(f"本次请求返回的状态码:{result['code']}")
+            logger.success(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
             return f'删除绑定成功,删除的账号为{param_server}：{account_name}'
         elif result['code'] == 500:
