@@ -3,9 +3,10 @@ import httpx
 import traceback
 import jinja2
 import re
+import time
 from datetime import datetime
 from pathlib import Path
-from .data_source import servers,set_recentparams
+from .data_source import servers,set_recentparams,set_damageColor,set_winColor,set_upinfo_color
 from .utils import match_keywords
 from nonebot_plugin_htmlrender import html_to_pic
 from .publicAPI import get_AccountIdByName
@@ -19,6 +20,7 @@ template_path = dir_path / "template"
 env = jinja2.Environment(
     loader=jinja2.FileSystemLoader(template_path), enable_async=True
 )
+env.globals.update(set_damageColor=set_damageColor,set_winColor=set_winColor,set_upinfo_color=set_upinfo_color,time=time,int=int,abs=abs,enumerate=enumerate)
 
 headers = {
     'Authorization': get_driver().config.api_token
@@ -74,11 +76,11 @@ async def get_RecentInfo(server_type,qqid,info):
         else:
             return '参数似乎出了问题呢'
         url = 'https://api.wows.shinoaki.com//api/wows/recent/v2/recent/info'
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
-            logger.info(f"本次请求返回的状态码:{result['code']}")
+            logger.success(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200:
             if result['data']['shipData'][0]['shipData']:
                 template = env.get_template("wws-info-recent.html")
