@@ -5,7 +5,7 @@ import asyncio
 from pathlib import Path
 from nonebot.adapters.onebot.v11 import MessageSegment
 from .data_source import servers,set_shipparams,tiers,number_url_homes,set_ShipRank_Numbers
-from .utils import match_keywords
+from .utils import match_keywords,get_bot
 from nonebot_plugin_htmlrender import html_to_pic,text_to_pic
 from .wws_ship import ShipSecletProcess,ShipSlectState
 from.publicAPI import get_ship_byName
@@ -28,8 +28,9 @@ headers = {
     'Content-Type':'application/json',
 }
 
-async def get_ShipRank(qqid,info,bot):
+async def get_ShipRank(qqid,info,ev):
     try:
+        bot = get_bot()
         if len(info) == 2:
             param_server,info = await match_keywords(info,servers)
             if param_server and not param_server == 'cn':
@@ -39,7 +40,7 @@ async def get_ShipRank(qqid,info,bot):
         else:
             return '参数似乎出了问题呢'
         shipList = await get_ship_byName(str(info[0]))
-        logger.info(f"{shipList}")
+        logger.success(f"{shipList}")
         if shipList:
             if len(shipList) < 2:
                 select_shipId = shipList[0][0]
@@ -52,7 +53,7 @@ async def get_ShipRank(qqid,info,bot):
                     msg += f"{flag}：{tiers[each[3]-1]} {each[1]}\n"
                 ShipSecletProcess[qqid] = ShipSlectState(False, None, shipList)
                 img = await text_to_pic(text=msg,css_path = str(template_path/"text-ship.css"),width=250) 
-                await bot.send(MessageSegment.image(img))
+                await bot.send(ev,MessageSegment.image(img))
                 a = 0
                 while a < 40 and not ShipSecletProcess[qqid].state:
                     a += 1
@@ -92,10 +93,10 @@ async def search_ShipRank_Yuyuko(shipId,server):
                 "server":server,
                 "shipId":int(shipId)
             }
-            logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
+            logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
             resp = await client.get(url, params=params,timeout=None)
             result = resp.json()
-            logger.info(f"本次请求返回的状态码:{result['code']}")
+            logger.success(f"本次请求返回的状态码:{result['code']}")
             if result['code'] == 200 and result['data']:
                 template = env.get_template("ship-rank.html")
                 result_data = {"data":result['data']}
@@ -113,10 +114,10 @@ async def search_ShipRank_Yuyuko(shipId,server):
 async def search_ShipRank_Numbers(url,server,shipId):
     try:
         content = None
-        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}")
+        logger.success(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}")
         async with httpx.AsyncClient() as client:
             resp = await client.get(url, timeout=None)
-            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
+            logger.success(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
         soup = BeautifulSoup(resp.content, 'html.parser')
         data = soup.select('tr[class="cells-middle"]')
         infoList = await set_ShipRank_Numbers(data,server,shipId)
@@ -137,7 +138,7 @@ async def post_ShipRank(data):
             url = 'https://api.wows.shinoaki.com/upload/numbers/data/v2/upload/ship/rank'
             resp = await client.post(url, json = data, timeout=None)
             result = resp.json()
-            logger.info(result)
+            logger.success(result)
     except (TimeoutError, ConnectTimeout):
         logger.warning(traceback.format_exc())
     except Exception:
